@@ -26,20 +26,19 @@ class QLabel;
 class QLineEdit;
 class QHelpIndexWidget;
 
-class CHelpIndex : public QWidget
-{
-    Q_OBJECT
-public:
-    CHelpIndex(QHelpEngine * engine, QWidget * parent);
-    virtual ~CHelpIndex() = default;
+class CHelpIndex : public QWidget {
+  Q_OBJECT
+ public:
+  CHelpIndex(QHelpEngine* engine, QWidget* parent);
+  virtual ~CHelpIndex() = default;
 
-private slots:
-    void slotSearch(const QString& text);
-private:
-    QLabel * labelSearch;
-    QLineEdit * lineSearch;
-    QHelpIndexWidget * index;
+ private slots:
+  void slotSearch(const QString& text);
+
+ private:
+  QLabel* labelSearch;
+  QLineEdit* lineSearch;
+  QHelpIndexWidget* index;
 };
 
-#endif //CHELPINDEX_H
-
+#endif  // CHELPINDEX_H
