@@ -27,7 +27,7 @@
 #include "units/IUnit.h"
 
 void CDemTreeWidget::dragMoveEvent(QDragMoveEvent* event) {
-  CDemItem* item = dynamic_cast<CDemItem*>(itemAt(event->pos()));
+  CDemItem* item = dynamic_cast<CDemItem*>(itemAt(event->position().toPoint()));
 
   if (item && item->isActivated()) {
     event->setDropAction(Qt::MoveAction);
@@ -91,7 +91,7 @@ void CDemList::sort() {
   std::sort(items1.begin(), items1.end(), &sortByName<CDemItem>);
 
   QList<QTreeWidgetItem*> items2;
-  for (CDemItem* item : qAsConst(items1)) {
+  for (CDemItem* item : std::as_const(items1)) {
     items2 << item;
   }
   treeWidget->addTopLevelItems(items2);
@@ -193,35 +193,6 @@ void CDemList::slotContextMenu(const QPoint& point) {
 
 void CDemList::slotReloadDem() { CDemDraw::setupDemPath(CDemDraw::getDemPaths()); }
 
-static void saveResource(const QString& name, QDir& dir) {
-  QFile resource1(QString("://dem/%1").arg(name));
-  resource1.open(QIODevice::ReadOnly);
-
-  QFile file(dir.absoluteFilePath(name));
-  file.open(QIODevice::WriteOnly);
-  file.write(resource1.readAll());
-  file.close();
-}
-
-void CDemList::slotDemHonk() {
-  QString demPath = CMainWindow::self().getDemPath();
-  if (demPath.isEmpty()) {
-    demPath = QDir::homePath();
-  }
-
-  demPath = QFileDialog::getExistingDirectory(CMainWindow::getBestWidgetForParent(),
-                                              tr("Where do you want to store DEMs?"), demPath);
-  if (demPath.isEmpty()) {
-    return;
-  }
-
-  QDir dir(demPath);
-
-  saveResource("World_Online_SRTM900.wcs", dir);
-
-  CDemDraw::setupDemPath(demPath);
-}
-
 void CDemList::slotFilter(const QString& str) {
   actionClearFilter->setIcon(str.isEmpty() ? QIcon("://icons/32x32/Filter.png") : QIcon("://icons/32x32/Cancel.png"));
 
