@@ -19,7 +19,12 @@
 #ifndef CDEVICEWATCHERLINUX_H
 #define CDEVICEWATCHERLINUX_H
 
+#include "device/IDevice.h"
 #include "device/IDeviceWatcher.h"
+#include "device/dbus/org.gtk.vfs.MTPVolumeMonitor.h"
+#include "device/dbus/org.gtk.vfs.MountTracker.h"
+#include "device/dbus/org.kde.kmtp.Daemon.h"
+#include "device/dbus/org.kde.kmtp.Device.h"
 
 class QDBusObjectPath;
 
@@ -34,8 +39,24 @@ class CDeviceWatcherLinux : public IDeviceWatcher {
   void slotDeviceRemoved(const QDBusObjectPath& path, const QStringList& list);
   void slotUpdate() override;
 
+  void slotKMTPDeviceChanged();
+
+  void slotGVFSMtpVolumeAdded(const QString& dbus_name, const QString& id, GVFSMtpVolume volume);
+  void slotGVFSMtpVolumeRemoved(const QString& dbus_name, const QString& id, GVFSMtpVolume volume);
+
+  void slotGVFSMounted(GVFSMount mount);
+  void slotGVFSUnmounted(GVFSMount mount);
+
  private:
   QString readMountPoint(const QString& path);
+  void addKMtpDevice(org::kde::kmtp::Device& device, const QString& deviceKey, IDevice::type_e deviceType);
+  void addGVFSMtpDevice(const GVFSMount& mount, const QStringList& storages, IDevice::type_e deviceType);
+
+  org::kde::kmtp::Daemon* kMtpDaemon;
+  QMap<QString, QStringList> knownMtpDevices;
+
+  org::gtk::Private::RemoteVolumeMonitor* gvfsMtpVolumeMonitor;
+  org::gtk::vfs::MountTracker* gvfsMountTracker;
 };
 
 #endif  // CDEVICEWATCHERLINUX_H
