@@ -20,6 +20,7 @@
 
 #include "CMainWindow.h"
 #include "canvas/CCanvas.h"
+#include "gis/fit2/CFit2Project.h"
 #if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
 #include "device/CDeviceWatcherLinux.h"
 #endif
@@ -44,7 +45,6 @@
 #include "gis/db/CSelectDBFolder.h"
 #include "gis/db/CSetupFolder.h"
 #include "gis/db/macros.h"
-#include "gis/fit/CFitProject.h"
 #include "gis/gpx/CGpxProject.h"
 #include "gis/ovl/CGisItemOvlArea.h"
 #include "gis/prj/IGisProject.h"
@@ -246,18 +246,18 @@ CGisListWks::~CGisListWks() {}
 void CGisListWks::configDB() {
   QSqlQuery query(db);
 
-  QUERY_RUN("PRAGMA locking_mode=EXCLUSIVE", return )
-  QUERY_RUN("PRAGMA synchronous=OFF", return )
-  QUERY_RUN("PRAGMA temp_store=MEMORY", return )
-  QUERY_RUN("PRAGMA default_cache_size=50", return )
-  QUERY_RUN("PRAGMA page_size=8192", return )
+  QUERY_RUN("PRAGMA locking_mode=EXCLUSIVE", return)
+  QUERY_RUN("PRAGMA synchronous=OFF", return)
+  QUERY_RUN("PRAGMA temp_store=MEMORY", return)
+  QUERY_RUN("PRAGMA default_cache_size=50", return)
+  QUERY_RUN("PRAGMA page_size=8192", return)
 
   // When migrating the database these tables are used.
   // Due to caching they can't be dropped right after the
   // migration. That is why we look for them on startup.
   // And delete them as a second chance.
   if (query.exec("select * from tmp_workspace")) {
-    QUERY_RUN("DROP TABLE tmp_workspace;", return );
+    QUERY_RUN("DROP TABLE tmp_workspace;", return);
   }
 
   if (!query.exec("SELECT version FROM versioninfo")) {
@@ -333,8 +333,8 @@ void CGisListWks::migrateDB1to2() {
 void CGisListWks::migrateDB2to3() {
   QSqlQuery query(db);
 
-  QUERY_RUN("BEGIN TRANSACTION;", return )
-  QUERY_RUN("ALTER TABLE workspace RENAME TO tmp_workspace;", return )
+  QUERY_RUN("BEGIN TRANSACTION;", return)
+  QUERY_RUN("ALTER TABLE workspace RENAME TO tmp_workspace;", return)
   QUERY_RUN(
       "CREATE TABLE workspace ("
       "id             INTEGER PRIMARY KEY AUTOINCREMENT,"
@@ -345,10 +345,10 @@ void CGisListWks::migrateDB2to3() {
       "visible        BOOLEAN DEFAULT TRUE,"
       "data           BLOB NOT NULL"
       ")",
-      return );
-  QUERY_RUN("INSERT INTO workspace(id,type,name,keyqms,changed,visible,data) SELECT * FROM tmp_workspace;", return )
-  QUERY_RUN("COMMIT;", return )
-  QUERY_RUN("DROP TABLE tmp_workspace;", return )
+      return);
+  QUERY_RUN("INSERT INTO workspace(id,type,name,keyqms,changed,visible,data) SELECT * FROM tmp_workspace;", return)
+  QUERY_RUN("COMMIT;", return)
+  QUERY_RUN("DROP TABLE tmp_workspace;", return)
 }
 
 void CGisListWks::migrateDB3to4() {
@@ -389,7 +389,7 @@ void CGisListWks::dragMoveEvent(QDragMoveEvent* e) {
   setDragDropMode(QAbstractItemView::DragDrop);
 
   QTreeWidgetItem* item1 = currentItem();
-  QTreeWidgetItem* item2 = itemAt(e->pos());
+  QTreeWidgetItem* item2 = itemAt(e->position().toPoint());
 
   // changing the item order is only valid for single selected items
   if (selectedItems().count() == 1) {
@@ -523,13 +523,13 @@ void CGisListWks::dropEvent(QDropEvent* e) {
    */
   if (items.size() == 1) {
     // calc. index offset (below/above item)
-    QRect r = visualItemRect(itemAt(e->pos()));
+    QRect r = visualItemRect(itemAt(e->position().toPoint()));
     int y1 = r.top() + r.height() / 2;
-    int y2 = e->pos().y();
+    int y2 = e->position().toPoint().y();
     int off = y2 > y1 ? 1 : 0;
 
     IGisProject* prj1 = dynamic_cast<IGisProject*>(currentItem());
-    IGisProject* prj2 = dynamic_cast<IGisProject*>(itemAt(e->pos()));
+    IGisProject* prj2 = dynamic_cast<IGisProject*>(itemAt(e->position().toPoint()));
     if (prj1 && prj2) {
       prj2->setFlags(prj2->flags() & ~Qt::ItemIsDropEnabled);
       QTreeWidget::dropEvent(e);
@@ -539,7 +539,7 @@ void CGisListWks::dropEvent(QDropEvent* e) {
     }
 
     CGisItemWpt* wpt1 = dynamic_cast<CGisItemWpt*>(currentItem());
-    CGisItemWpt* wpt2 = dynamic_cast<CGisItemWpt*>(itemAt(e->pos()));
+    CGisItemWpt* wpt2 = dynamic_cast<CGisItemWpt*>(itemAt(e->position().toPoint()));
 
     if (wpt1 && wpt2) {
       if (wpt1->parent() == wpt2->parent()) {
@@ -555,7 +555,7 @@ void CGisListWks::dropEvent(QDropEvent* e) {
     }
 
     CGisItemTrk* trk1 = dynamic_cast<CGisItemTrk*>(currentItem());
-    CGisItemTrk* trk2 = dynamic_cast<CGisItemTrk*>(itemAt(e->pos()));
+    CGisItemTrk* trk2 = dynamic_cast<CGisItemTrk*>(itemAt(e->position().toPoint()));
 
     if (trk1 && trk2) {
       if (trk1->parent() == trk2->parent()) {
@@ -571,7 +571,7 @@ void CGisListWks::dropEvent(QDropEvent* e) {
     }
 
     CGisItemRte* rte1 = dynamic_cast<CGisItemRte*>(currentItem());
-    CGisItemRte* rte2 = dynamic_cast<CGisItemRte*>(itemAt(e->pos()));
+    CGisItemRte* rte2 = dynamic_cast<CGisItemRte*>(itemAt(e->position().toPoint()));
 
     if (rte1 && rte2) {
       if (rte1->parent() == rte2->parent()) {
@@ -587,7 +587,7 @@ void CGisListWks::dropEvent(QDropEvent* e) {
     }
 
     CGisItemOvlArea* area1 = dynamic_cast<CGisItemOvlArea*>(currentItem());
-    CGisItemOvlArea* area2 = dynamic_cast<CGisItemOvlArea*>(itemAt(e->pos()));
+    CGisItemOvlArea* area2 = dynamic_cast<CGisItemOvlArea*>(itemAt(e->position().toPoint()));
 
     if (area1 && area2) {
       if (area1->parent() == area2->parent()) {
@@ -604,7 +604,7 @@ void CGisListWks::dropEvent(QDropEvent* e) {
   }
 
   // check if item at position is a project and insert a copy of all selected items
-  IGisProject* project = dynamic_cast<IGisProject*>(itemAt(e->pos()));
+  IGisProject* project = dynamic_cast<IGisProject*>(itemAt(e->position().toPoint()));
   if (project) {
     project->blockUpdateItems(true);
 
@@ -624,25 +624,15 @@ void CGisListWks::dropEvent(QDropEvent* e) {
     project->blockUpdateItems(false);
   }
 
-  IDevice* device = dynamic_cast<IDevice*>(itemAt(e->pos()));
+  IDevice* device = dynamic_cast<IDevice*>(itemAt(e->position().toPoint()));
   if (device) {
-    IGisProject* project = dynamic_cast<IGisProject*>(currentItem());
-    if (project) {
-      CCanvas* canvas = CMainWindow::self().getVisibleCanvas();
-      if (canvas) {
-        canvas->reportStatus(
-            "device",
-            tr("<b>Update devices</b><p>Update %1<br/>Please wait...</p>").arg(device->text(CGisListWks::eColumnName)));
-        canvas->update();
-        qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
-      }
-
-      int lastResult = CSelectCopyAction::eResultNone;
-      device->insertCopyOfProject(project, lastResult);
-
-      if (canvas) {
-        canvas->reportStatus("device", "");
+    const QList<QTreeWidgetItem*>& items = selectedItems();
+    for (QTreeWidgetItem* item : items) {
+      IGisProject* project = dynamic_cast<IGisProject*>(item);
+      if (project == nullptr) {
+        continue;
       }
+      syncPrjToDevices(project, {device->getKey()});
     }
   }
 
@@ -733,7 +723,7 @@ void CGisListWks::slotSaveWorkspace() {
   }
 
   QSqlQuery query(db);
-  QUERY_RUN("DELETE FROM workspace", return )
+  QUERY_RUN("DELETE FROM workspace", return)
 
   qDebug() << "slotSaveWorkspace()";
 
@@ -741,7 +731,7 @@ void CGisListWks::slotSaveWorkspace() {
   PROGRESS_SETUP(tr("Saving workspace. Please wait."), 0, total, this);
 
   for (int i = 0; i < total; i++) {
-    PROGRESS(i, return );
+    PROGRESS(i, return);
 
     IGisProject* project = dynamic_cast<IGisProject*>(topLevelItem(i));
     if (nullptr == project) {
@@ -754,6 +744,9 @@ void CGisListWks::slotSaveWorkspace() {
     stream.setByteOrder(QDataStream::LittleEndian);
 
     project->IGisProject::operator>>(stream);
+    if (project->getName() == "") {
+      continue;
+    }
 
     query.prepare(
         "INSERT INTO workspace (type, keyqms, name, changed, visible, data) VALUES (:type, :keyqms, :name, :changed, "
@@ -783,15 +776,27 @@ void CGisListWks::slotLoadWorkspace() {
 
   QSqlQuery query(db);
 
-  QUERY_RUN("SELECT type, keyqms, name, changed, visible, data FROM workspace", return )
+  QUERY_RUN("SELECT type, keyqms, name, changed, visible, data FROM workspace", return)
 
-  {  // open context for progress dialog
-    const int total = query.size();
+  { // open context for progress dialog
+    //Refer to https://stackoverflow.com/questions/26495049/qsqlquery-size-always-returns-1
+    qreal total = 0;
+    if (db.driver()->hasFeature(QSqlDriver::QuerySize)) {
+      total = query.size();
+    } else {
+      if(query.last())
+      {
+        total =  query.at() + 1;
+        query.first();
+        query.previous();
+      }
+    }
     PROGRESS_SETUP(tr("Loading workspace. Please wait."), 0, total, this);
+    progress.show();
     quint32 progCnt = 0;
 
     while (query.next()) {
-      PROGRESS(progCnt++, return );
+      PROGRESS(progCnt++, return);
 
       int type = query.value(0).toInt();
       QString name = query.value(2).toString();
@@ -855,7 +860,7 @@ void CGisListWks::slotLoadWorkspace() {
         }
 
         case IGisProject::eTypeFit: {
-          project = new CFitProject(name, this);
+          project = new CFit2Project(name, this);
           project->setCheckState(CGisListDB::eColumnCheckbox, visible);
           *project << stream;
           break;
@@ -1783,8 +1788,6 @@ void CGisListWks::slotGeoSearch(bool on) {
 }
 
 void CGisListWks::slotSyncWksDev() {
-  CGisListWksEditLock lock(true, IGisItem::mutexItems);
-
   if (IDevice::count() == 0) {
     return;
   }
@@ -1811,7 +1814,14 @@ void CGisListWks::slotSyncWksDev() {
       }
     }
   }
-  syncPrjToDevices(project, keys);
+  const QList<QTreeWidgetItem*>& items = selectedItems();
+  for (QTreeWidgetItem* item : items) {
+    IGisProject* project = dynamic_cast<IGisProject*>(item);
+    if (project == nullptr) {
+      continue;
+    }
+    syncPrjToDevices(project, keys);
+  }
 }
 
 void CGisListWks::slotSyncDevWks() {
@@ -2025,7 +2035,7 @@ bool CGisListWks::event(QEvent* e) {
           }
         }
 
-        for (CDBProject* project : qAsConst(projects)) {
+        for (CDBProject* project : std::as_const(projects)) {
           project->blockUpdateItems(false);
         }
         e->accept();
