@@ -44,6 +44,17 @@ CGpxProject::CGpxProject(const QString& filename, IDevice* parent) : IGisProject
   blockUpdateItems(false);
 }
 
+CGpxProject::CGpxProject(QFile& file, const QString& filename, IDevice* parent)
+    : IGisProject(eTypeGpx, filename, parent) {
+  setIcon(CGisListWks::eColumnIcon, QIcon("://icons/32x32/GpxProject.png"));
+  blockUpdateItems(true);
+  loadGpx(file, filename, this);
+  setName(QFileInfo(filename).completeBaseName().replace("_", " "));
+  setupName("");
+  markAsSaved();
+  blockUpdateItems(false);
+}
+
 CGpxProject::CGpxProject(const QString& filename, const IGisProject* project, IDevice* parent)
     : IGisProject(eTypeGpx, filename, parent) {
   setIcon(CGisListWks::eColumnIcon, QIcon("://icons/32x32/GpxProject.png"));
@@ -93,15 +104,20 @@ void CGpxProject::loadGpx(const QString& filename, CGpxProject* project) {
   if (!file.open(QIODevice::ReadOnly)) {
     throw tr("Failed to open %1").arg(filename);
   }
+  loadGpx(file, filename, project);
+}
 
+void CGpxProject::loadGpx(QFile& file, const QString& filename, CGpxProject* project) {
   // load file content to xml document
   QDomDocument xml;
-  QString msg;
-  int line;
-  int column;
-  if (!xml.setContent(&file, false, &msg, &line, &column)) {
+  const QDomDocument::ParseResult& result = xml.setContent(&file);
+  if (!result) {
     file.close();
-    throw tr("Failed to read: %1\nline %2, column %3:\n %4").arg(filename).arg(line).arg(column).arg(msg);
+    throw tr("Failed to read: %1\nline %2, column %3:\n %4")
+        .arg(filename)
+        .arg(result.errorLine)
+        .arg(result.errorColumn)
+        .arg(result.errorMessage);
   }
   file.close();
 
@@ -220,7 +236,7 @@ bool CGpxProject::saveAs(const QString& fn, IGisProject& project, bool strictGpx
 
     // load file content to xml document
     QDomDocument xml;
-    if (xml.setContent(&file, false)) {
+    if (xml.setContent(&file)) {
       const QDomElement& docElem = xml.documentElement();
       const QDomNamedNodeMap& attr = docElem.attributes();
       createdByQMS = attr.namedItem("creator").nodeValue().startsWith("QMapShack");
@@ -243,6 +259,10 @@ bool CGpxProject::saveAs(const QString& fn, IGisProject& project, bool strictGpx
     file.close();
   }
 
+  return saveAs(file, _fn_, project, strictGpx11);
+}
+
+bool CGpxProject::saveAs(QFile& file, const QString& filename, IGisProject& project, bool strictGpx11) {
   //  ---- start content of gpx
   QDomDocument doc;
   QDomNode gpx = project.writeMetadata(doc, strictGpx11);
@@ -334,17 +354,17 @@ bool CGpxProject::saveAs(const QString& fn, IGisProject& project, bool strictGpx
 
   bool res = true;
   try {
-    if (!file.open(QIODevice::WriteOnly)) {
-      throw tr("Failed to create file '%1'").arg(_fn_);
+    if (!file.isOpen() && !file.open(QIODevice::WriteOnly)) {
+      throw tr("Failed to create file '%1'").arg(filename);
     }
     QTextStream out(&file);
-    out.setCodec("UTF-8");
+    out.setEncoding(QStringConverter::Utf8);
     out << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << Qt::endl;
 
     out << doc.toString();
     file.close();
     if (file.error() != QFile::NoError) {
-      throw tr("Failed to write file '%1'").arg(_fn_);
+      throw tr("Failed to write file '%1'").arg(filename);
     }
   } catch (const QString& msg) {
     // as saveAs() can be called from the thread that exports a database showing the
