@@ -251,7 +251,7 @@ void CRouterBRouterSetup::readLocalProfiles() {
       changed = true;
     }
   }
-  for (const QString& profile : qAsConst(installedProfiles)) {
+  for (const QString& profile : std::as_const(installedProfiles)) {
     if (!localProfiles.contains(profile)) {
       localProfiles << profile;
       changed = true;
@@ -532,10 +532,10 @@ void CRouterBRouterSetup::loadOnlineVersionFinished(QNetworkReply* reply) {
     return;
   }
   const QString gpx(reply->readAll());
-  const QRegExp reVersion = QRegExp("^<\\?xml.+<gpx.+creator=\"(.*)\"");
-
-  if (reVersion.indexIn(gpx) > -1) {
-    parseBRouterVersion(reVersion.cap(1));
+  static const QRegularExpression reVersion("^<\\?xml.+<gpx.+creator=\"([^\"]*)\".*$",QRegularExpression::DotMatchesEverythingOption|QRegularExpression::MultilineOption);
+  const QRegularExpressionMatch& match = reVersion.match(gpx);
+  if (match.hasMatch()) {
+    parseBRouterVersion(match.captured(1));
     return;
   }
   emit sigError("invalid reply", "response is not brouter-gpx");
@@ -544,15 +544,16 @@ void CRouterBRouterSetup::loadOnlineVersionFinished(QNetworkReply* reply) {
 void CRouterBRouterSetup::parseBRouterVersion(const QString& text) {
   // version string is either like "BRouter 1.4.9 / 24092017"
   // or (without the date) like "BRouter-1.4.9"
-  QRegExp reVersion("\\bBRouter[- ](\\d+)\\.(\\d+)\\.(\\d+)\\b");
-  if (reVersion.indexIn(text) > -1) {
+  static const QRegularExpression reVersion("\\bBRouter[- ](\\d+)\\.(\\d+)\\.(\\d+)\\b");
+  const QRegularExpressionMatch match = reVersion.match(text);
+  if (match.hasMatch()) {
     bool ok;
-    versionMajor = reVersion.cap(1).toInt(&ok);
+    versionMajor = match.captured(1).toInt(&ok);
     if (ok) {
-      versionMinor = reVersion.cap(2).toInt(&ok);
+      versionMinor = match.captured(2).toInt(&ok);
     }
     if (ok) {
-      versionPatch = reVersion.cap(3).toInt(&ok);
+      versionPatch = match.captured(3).toInt(&ok);
     }
     if (ok) {
       emit sigVersionChanged();
@@ -582,7 +583,7 @@ CRouterBRouterLocalSetupStatus CRouterBRouterSetup::checkLocalBRouterInstallatio
   bool isJavaOutdated =
       classMajorVersion != NOINT && (javaMajorVersion == NOINT || javaMajorVersion < classMajorVersion);
 
-  if (isBRouterJar && !isJavaOutdated) {
+  if (isBRouterJar && isJavaValid) {
     QProcess cmd;
 
     cmd.setWorkingDirectory(localDir);
@@ -601,7 +602,7 @@ CRouterBRouterLocalSetupStatus CRouterBRouterSetup::checkLocalBRouterInstallatio
 
   bool isValidBRouterVersion = versionMajor != NOINT && versionMinor != NOINT && versionPatch != NOINT;
 
-  isLocalBRouterValid = isBRouterJar && isValidBRouterVersion && isJavaExisting && !isJavaOutdated;
+  isLocalBRouterValid = isValidBRouterVersion;
 
   return CRouterBRouterLocalSetupStatus(isJavaExisting, isJavaValid, isJavaOutdated, isBRouterJar, isBRouterCandidate,
                                         isValidBRouterVersion);
@@ -669,7 +670,7 @@ void CRouterBRouterSetup::displayProfileAsync(const QString& profile) {
       file.open(QIODevice::ReadOnly);
       const QByteArray& content = file.readAll();
       file.close();
-      emit sigDisplayOnlineProfileFinished(profile, QString(content));
+      emit sigDisplayOnlineProfileFinished(profile, QString(content.data()));
     }
   } else {
     Q_ASSERT(installMode == eModeOnline);
@@ -710,7 +711,7 @@ void CRouterBRouterSetup::loadOnlineProfileFinished(QNetworkReply* reply) {
     readLocalProfiles();
   } else {
     Q_ASSERT(mode == eProfileDisplay);
-    emit sigDisplayOnlineProfileFinished(profile, QString(content));
+    emit sigDisplayOnlineProfileFinished(profile, QString(content.data()));
   }
 }
 
@@ -750,10 +751,10 @@ bool CRouterBRouterSetup::isLocalBRouterDefaultDir() const { return localDir ==
 void CRouterBRouterSetup::setJava(const QString& path) {
   localJavaExecutable = path;
 
-  if (tryJavaVersion({"-version"}, "[\\S]+ version \"(\\d+)(\\.\\d+)*\" .*")) {
+  if (tryJavaVersion({"-version"}, "[\\S]+ version \"(\\d+)(\\.\\d+)*(-\\S+)?\" .*")) {
     return;
   }
-  if (tryJavaVersion({"--version"}, "[\\S]+ (\\d+)(\\.\\d+)* .*")) {
+  if (tryJavaVersion({"--version"}, "[\\S]+ (\\d+)(\\.\\d+)*(-\\S+)? .*")) {
     return;
   }
 
@@ -764,6 +765,10 @@ bool CRouterBRouterSetup::tryJavaVersion(const QStringList& arguments, const QSt
   QProcess cmd;
   QRegularExpression re(pattern);
 
+  if (localJavaExecutable == "") {
+    return false;
+  }
+
   cmd.setWorkingDirectory(localDir);
   cmd.start(localJavaExecutable, arguments);
 
