@@ -36,7 +36,6 @@ class QSqlDatabase;
 class CQlgtWpt;
 class QTextEdit;
 class QDir;
-class CFitStream;
 class CGisItemWpt : public IGisItem {
   Q_DECLARE_TR_FUNCTIONS(CGisItemWpt)
  public:
@@ -152,7 +151,7 @@ class CGisItemWpt : public IGisItem {
 
   CGisItemWpt(const CQlgtWpt& wpt1, IGisProject* project = nullptr);
 
-  CGisItemWpt(CFitStream& stream, IGisProject* project);
+  CGisItemWpt(const wpt_t& data, IGisProject* project);
 
   virtual ~CGisItemWpt();
 
@@ -305,7 +304,7 @@ class CGisItemWpt : public IGisItem {
   void setSymbol() override;
   void readGpx(const QDomNode& xml);
   void readTwoNav(const CTwoNavProject::wpt_t& tnvWpt);
-  void readWptFromFit(CFitStream& stream);
+
   void readGcExt(const QDomNode& xmlCache);
   void writeGcExt(QDomNode& xmlCache);
   void drawBubble(QPainter& p);
