@@ -19,38 +19,37 @@
 #ifndef CSELECTPROJECTDIALOG_H
 #define CSELECTPROJECTDIALOG_H
 
+#include <QDialog>
+
 #include "gis/prj/IGisProject.h"
 #include "ui_ISelectProjectDialog.h"
-#include <QDialog>
 
 class QTreeWidget;
 
-class CSelectProjectDialog : public QDialog, private Ui::ISelectProjectDialog
-{
-    Q_OBJECT
-public:
-    CSelectProjectDialog(QString& key, QString& name, IGisProject::type_e& type, QTreeWidget* parent);
-    virtual ~CSelectProjectDialog();
+class CSelectProjectDialog : public QDialog, private Ui::ISelectProjectDialog {
+  Q_OBJECT
+ public:
+  CSelectProjectDialog(QString& key, QString& name, IGisProject::type_e& type, QTreeWidget* parent);
+  virtual ~CSelectProjectDialog();
 
-public slots:
-    void accept() override;
-    void reject() override;
+ public slots:
+  void accept() override;
+  void reject() override;
 
-private slots:
-    void slotItemClicked(QListWidgetItem* item);
-    void slotItemDoubleClicked(QListWidgetItem* item);
-    void slotProjectChanged(const QString& text);
-    void slotProjectEdited(const QString& text);
-    void slotTypeChanged();
+ private slots:
+  void slotItemClicked(QListWidgetItem* item);
+  void slotItemDoubleClicked(QListWidgetItem* item);
+  void slotProjectChanged(const QString& text);
+  void slotProjectEdited(const QString& text);
+  void slotTypeChanged();
 
-private:
-    void setType(IGisProject::type_e& t);
+ private:
+  void setType(IGisProject::type_e& t);
 
-    static QString lastkey;
-    QString& key;
-    QString& name;
-    IGisProject::type_e& type;
+  static QString lastkey;
+  QString& key;
+  QString& name;
+  IGisProject::type_e& type;
 };
 
-#endif //CSELECTPROJECTDIALOG_H
-
+#endif  // CSELECTPROJECTDIALOG_H
