@@ -199,7 +199,7 @@ bool CRtAisInfo::verifyLine(const QString& line) {
     cs ^= data[i];
   }
 
-  return line.rightRef(2).toInt(0, 16) == cs;
+  return line.right(2).toInt(0, 16) == cs;
 }
 
 void CRtAisInfo::nmeaVDM(const QStringList& tokens) {
@@ -500,13 +500,15 @@ void CRtAisInfo::getString(const QByteArray& data, QString& string, int start, i
   for (int i = start; i < end && end - i >= 6; i += 6) {
     int c = get6bitInt(data, i, 6) & 0x3F;
     if (c < 32) {
-      string.insert(ci++, c + 64);
+      string.insert(ci++, QChar(c + 64));
     } else {
-      string.insert(ci++, c);
+      string.insert(ci++, QChar(c));
     }
   }
-  string.replace(QRegExp("^[@\\s]+"), "");
-  string.replace(QRegExp("[@\\s]+$"), "");
+  static const QRegularExpression re1("^[@\\s]+");
+  static const QRegularExpression re2("[@\\s]+$");
+  string.replace(re1, "");
+  string.replace(re2, "");
 }
 
 void CRtAisInfo::startRecord(const QString& filename) {
