@@ -26,7 +26,7 @@ CLogHandler::CLogHandler(QString logDirectory, bool writeToFile, bool debugOutpu
       logFile(QDir(logDirectory).absoluteFilePath(logfileName())),
       fileStream(&logFile) {
   if (writeToFile) {
-    fileStream.setCodec("UTF-8");
+    fileStream.setEncoding(QStringConverter::Utf8);
     logFile.open(QIODevice::WriteOnly | QIODevice::Append);
   }
   qSetMessagePattern("%{time yyyy-MM-dd h:mm:ss.zzz} [%{type}] %{message}");
